@@ -14,12 +14,13 @@ BEGIN {  # Script is relocatable. See http://ccobb.net/ptools/
   my($top,$app)=($1,$2) if ( getcwd() =~ m#^(.*)(?=/)/?(.*)#);
   $ENV{'PTOOLS_TOPDIR'} = $top;  $ENV{'PTOOLS_APPDIR'} = $app;
 } #-----------------------------------------------------------
+use lib "$ENV{'PTOOLS_TOPDIR'}/$ENV{'PTOOLS_APPDIR'}";
 use PTools::Local;          # PTools local/global vars/methods
 
 # use POE::Component::GCS::Client qw( Message-based );
   use POE::Component::GCS::Client qw( Text-based );
 
-# Note: Using a config file is optional
+# Note: Using a config file is optional to run the client.
 #
 my $configFile = PTools::Local->path('app_cfgdir', "gcs/gcs.conf"); 
 
